@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::TABULO;
 ### ex: set ft=perl noai ts=4 sw=4:
 
-our $VERSION = '1.000002';
+our $VERSION = '1.000004';
 
 use 5.026; # Indented HEREDOC.
 use Data::Printer qw(p np);
@@ -697,7 +697,7 @@ sub _plug__GitCommitBuild__toReleaseBranch {
 
     (
     ["Git::CommitBuild/$label" => { branch => '', release_branch => $branch,  multiple_inheritence => 1 } ],
-    ["Git::Tag/$label"  => { branch => $branch, tag_format => $self->tag_format . " (for CPAN)" } ],
+    ["Git::Tag/$label"  => { branch => $branch, tag_format => $self->tag_format . "/CPAN)" } ],
     )
 }
 
@@ -939,7 +939,7 @@ Dist::Zilla::PluginBundle::Author::TABULO - A Dist::Zilla plugin bundle à la TA
 
 =head1 VERSION
 
-version 1.000002
+version 1.000004
 
 =head1 SYNOPSIS
 
